summaryrefslogtreecommitdiff
path: root/indra/newview/llviewermessage.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llviewermessage.cpp')
-rwxr-xr-xindra/newview/llviewermessage.cpp13
1 files changed, 11 insertions, 2 deletions
diff --git a/indra/newview/llviewermessage.cpp b/indra/newview/llviewermessage.cpp
index 871ed8c0df..931b16ccb7 100755
--- a/indra/newview/llviewermessage.cpp
+++ b/indra/newview/llviewermessage.cpp
@@ -5968,9 +5968,18 @@ bool attempt_standard_notification(LLMessageSystem* msgsystem)
// Special Marketplace update notification
if (notificationID == "SLM_UPDATE_FOLDER")
{
+ std::string state = llsdBlock["state"].asString();
+ llinfos << "Merov : SLM_UPDATE_FOLDER, state = " << state << ", id = " << llsdBlock["listing_id"].asInteger() << llendl;
// In general, no message will be displayed, all we want is to get the listing updated in the marketplace floater
- // If getListing() fails though, the message of the alert will be shown by the caller of attempt_standard_notification()
- return LLMarketplaceData::instance().getListing(llsdBlock["listing_id"].asInteger());
+ // If getListing() or deleteListing() fails though, the message of the alert will be shown by the caller of attempt_standard_notification()
+ if (state == "deleted")
+ {
+ return LLMarketplaceData::instance().deleteListing(llsdBlock["listing_id"].asInteger());
+ }
+ else
+ {
+ return LLMarketplaceData::instance().getListing(llsdBlock["listing_id"].asInteger());
+ }
}
LLNotificationsUtil::add(notificationID, llsdBlock);